@@ -25,7 +25,7 @@
 
 #include <iostream>
 
-#include <QtDBus/QtDBus>
+#include <QtDBus>
 
 #include <KAboutData>
 #include <QApplication>
@@ -40,6 +40,8 @@
 #include <KStartupInfo>
 #include <KActivities/ResourceInstance>
 
+#include <kworkspace.h>
+
 #include <QIcon>
 #include <QCommandLineParser>
 #include <QCommandLineOption>
@@ -127,7 +129,8 @@ KCMShellMultiDialog::KCMShellMultiDialog(KPageDialog::FaceType dialogFace, QWidg
 
     connect(this, &KCMShellMultiDialog::currentPageChanged,
             this, [this](KPageWidgetItem *newPage,KPageWidgetItem *oldPage) {
-                KCModuleProxy *activeModule = qobject_cast<KCModuleProxy *>(newPage->widget());
+                Q_UNUSED(oldPage);
+                KCModuleProxy *activeModule = newPage->widget()->findChild<KCModuleProxy *>();
                 if (activeModule) {
                     KActivities::ResourceInstance::notifyAccessed(QUrl("kcm:" + activeModule->moduleInfo().service()->storageId()),
                             "org.kde.systemsettings");
@@ -173,9 +176,15 @@ void KCMShell::appExit(const QString &appId, const QString &oldName, const QStri
 
 extern "C" Q_DECL_EXPORT int kdemain(int _argc, char *_argv[])
 {
+    const bool qpaVariable = qEnvironmentVariableIsSet("QT_QPA_PLATFORM");
+    KWorkSpace::detectPlatform(_argc, _argv);
+    KCMShell app(_argc, _argv);
+    if (!qpaVariable) {
+        // don't leak the env variable to processes we start
+        qunsetenv("QT_QPA_PLATFORM");
+    }
     KLocalizedString::setApplicationDomain("kcmshell5");
 
-    KCMShell app(_argc, _argv);
     app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
 
     KAboutData aboutData("kcmshell5", i18n("System Settings Module"),
@@ -190,10 +199,9 @@ extern "C" Q_DECL_EXPORT int kdemain(int _argc, char *_argv[])
     aboutData.addAuthor(i18n("Matthias Elter"),QString(), "elter@kde.org");
     aboutData.addAuthor(i18n("Matthias Ettrich"),QString(), "ettrich@kde.org");
     aboutData.addAuthor(i18n("Waldo Bastian"),QString(), "bastian@kde.org");
+    KAboutData::setApplicationData(aboutData);
 
     QCommandLineParser parser;
-    parser.addVersionOption();
-    parser.addHelpOption();
     aboutData.setupCommandLine(&parser);
 
     parser.addOption(QCommandLineOption(QStringLiteral("list"), i18n("List all possible modules")));
@@ -206,7 +214,6 @@ extern "C" Q_DECL_EXPORT int kdemain(int _argc, char *_argv[])
 
     parser.parse(app.arguments());
     aboutData.processCommandLine(&parser);
-    KAboutData::setApplicationData(aboutData);
 
     parser.process(app);
 
@@ -296,7 +303,7 @@ extern "C" Q_DECL_EXPORT int kdemain(int _argc, char *_argv[])
     }
 
     for (KService::List::ConstIterator it = modules.constBegin(); it != modules.constEnd(); ++it) {
-        dlg->addModule(*it, 0, moduleArgs);
+        dlg->addModule(*it, nullptr, moduleArgs);
     }
 
     if (parser.isSet("icon")) {
@@ -306,7 +313,6 @@ extern "C" Q_DECL_EXPORT int kdemain(int _argc, char *_argv[])
         dlg->setWindowIcon( QIcon::fromTheme(iconName) );
     }
 
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 7, 0))
     if (modules.count() == 1 && app.desktopFileName() == QLatin1String("org.kde.kcmshell5")) {
         const QString path = QStandardPaths::locate(QStandardPaths::GenericDataLocation,
                                                     QStringLiteral("kservices5/%1.desktop").arg(modules.first()->desktopEntryName()));
@@ -314,7 +320,6 @@ extern "C" Q_DECL_EXPORT int kdemain(int _argc, char *_argv[])
             app.setDesktopFileName(path);
         }
     }
-#endif
 
     dlg->show();
 
