@@ -49,7 +49,7 @@
 
 
 FileTypeDialog::FileTypeDialog( MimeTypeData* mime )
-  : QDialog( 0 ),
+  : QDialog( nullptr ),
     m_mimeTypeData(mime)
 {
     init();
@@ -141,8 +141,6 @@ int main(int argc, char ** argv)
 
     QCommandLineParser parser;
     aboutData.setupCommandLine(&parser);
-    parser.addHelpOption();
-    parser.addVersionOption();
     parser.addOption(QCommandLineOption(QStringList() << "parent", i18n("Makes the dialog transient for the window specified by winid"), "winid"));
     parser.addPositionalArgument("mimetype", i18n("File type to edit (e.g. text/html)"));
 
@@ -154,7 +152,7 @@ int main(int argc, char ** argv)
 
     QMimeDatabase db;
     QString arg = parser.positionalArguments().first();
-    MimeTypeData* mimeTypeData = 0;
+    MimeTypeData* mimeTypeData = nullptr;
     const bool createType = arg.startsWith('*');
     if ( createType ) {
         QString mimeString = "application/x-kdeuser%1";
