@@ -52,7 +52,7 @@
 
 // some globals
 
-static KProcess* proc = 0;
+static KProcess* proc = nullptr;
 static QString exe;
 static QString url;
 static QString windowtitle;
@@ -61,8 +61,8 @@ static int desktop = 0;
 static bool activate = false;
 static bool iconify = false;
 static bool fullscreen = false;
-static NET::States state = 0;
-static NET::States mask = 0;
+static NET::States state = {};
+static NET::States mask = {};
 static NET::WindowType windowtype = NET::Unknown;
 
 KStart::KStart()
@@ -162,7 +162,7 @@ const NET::WindowTypes SUPPORTED_WINDOW_TYPES_MASK = NET::NormalMask | NET::Desk
 
 void KStart::windowAdded(WId w){
 
-    KWindowInfo info = KWindowSystem::windowInfo( w, NET::WMWindowType | NET::WMName );
+    KWindowInfo info( w, NET::WMWindowType | NET::WMName );
 
     // always ignore these window types
     if( info.windowType( SUPPORTED_WINDOW_TYPES_MASK ) == NET::TopMenu
@@ -247,7 +247,7 @@ void KStart::applyStyle(WId w ) {
 	    ;
     }
 
-    NETWinInfo info( QX11Info::connection(), w, QX11Info::appRootWindow(), NET::WMState );
+    NETWinInfo info(QX11Info::connection(), w, QX11Info::appRootWindow(), NET::WMState, NET::Properties2());
 
     if ( ( desktop > 0 && desktop <= KWindowSystem::numberOfDesktops() )
          || desktop == NETWinInfo::OnAllDesktops )
@@ -303,14 +303,10 @@ int main( int argc, char *argv[] )
   aboutData.addAuthor( i18n("Matthias Ettrich"), QString(), "ettrich@kde.org" );
   aboutData.addAuthor( i18n("David Faure"), QString(), "faure@kde.org" );
   aboutData.addAuthor( i18n("Richard J. Moore"), QString(), "rich@kde.org" );
+  KAboutData::setApplicationData(aboutData);
 
   QCommandLineParser parser;
-  KAboutData::setApplicationData(aboutData);
-  parser.addVersionOption();
-  parser.addHelpOption();
   aboutData.setupCommandLine(&parser);
-
-
   parser.addOption(QCommandLineOption(QStringList() << QLatin1String("!+command"), i18n("Command to execute")));
   parser.addOption(QCommandLineOption(QStringList() << QLatin1String("service"), i18n("Alternative to <command>: desktop file to start. D-Bus service will be printed to stdout"), QLatin1String("desktopfile")));
   parser.addOption(QCommandLineOption(QStringList() << QLatin1String("url"), i18n("Optional URL to pass <desktopfile>, when using --service"), QLatin1String("url")));
